==> steampipe-0.21.7.tar.gz: steampipe-0.21.7/pkg/introspection/plugin_table_sql.go <==
package introspection

import (
	"fmt"

	"github.com/turbot/steampipe/pkg/constants"
	"github.com/turbot/steampipe/pkg/db/db_common"
	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
)

func GetPluginTableCreateSql() db_common.QueryWithArgs {
	return db_common.QueryWithArgs{
		Query: fmt.Sprintf(`CREATE TABLE IF NOT EXISTS %s.%s (
				plugin_instance TEXT NULL,
				plugin TEXT NOT NULL,
				memory_max_mb INTEGER,
				limiters JSONB NULL,
				file_name TEXT, 
				start_line_number INTEGER, 
				end_line_number INTEGER
		);`, constants.InternalSchema, constants.PluginInstanceTable),
	}
}

func GetPluginTablePopulateSql(plugin *modconfig.Plugin) db_common.QueryWithArgs {
	return db_common.QueryWithArgs{
		Query: fmt.Sprintf(`INSERT INTO %s.%s (
plugin,
plugin_instance,
memory_max_mb,
limiters,                
file_name,
start_line_number,
end_line_number
)
	VALUES($1,$2,$3,$4,$5,$6,$7)`, constants.InternalSchema, constants.PluginInstanceTable),
		Args: []any{
			plugin.Plugin,
			plugin.Instance,
			plugin.MemoryMaxMb,
			plugin.Limiters,
			plugin.FileName,
			plugin.StartLineNumber,
			plugin.EndLineNumber,
		},
	}
}

func GetPluginTableDropSql() db_common.QueryWithArgs {
	return db_common.QueryWithArgs{
		Query: fmt.Sprintf(
			`DROP TABLE IF EXISTS %s.%s;`,
			constants.InternalSchema,
			constants.PluginInstanceTable,
		),
	}
}

func GetPluginTableGrantSql() db_common.QueryWithArgs {
	return db_common.QueryWithArgs{
		Query: fmt.Sprintf(
			`GRANT SELECT ON TABLE %s.%s to %s;`,
			constants.InternalSchema,
			constants.PluginInstanceTable,
			constants.DatabaseUsersRole,
		),
	}
}

==> steampipe-0.23.3.tar.gz: steampipe-0.23.3/pkg/introspection/plugin_table_sql.go <==
package introspection

import (
	"fmt"

	"github.com/turbot/steampipe/pkg/constants"
	"github.com/turbot/steampipe/pkg/db/db_common"
	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
)

func GetPluginTableCreateSql() db_common.QueryWithArgs {
	return db_common.QueryWithArgs{
		Query: fmt.Sprintf(`CREATE TABLE IF NOT EXISTS %s.%s (
				plugin_instance TEXT,
				plugin TEXT NOT NULL,
				version TEXT ,
				memory_max_mb INTEGER,
				limiters JSONB,
				file_name TEXT, 
				start_line_number INTEGER, 
				end_line_number INTEGER				
		);`, constants.InternalSchema, constants.PluginInstanceTable),
	}
}

func GetPluginTablePopulateSql(plugin *modconfig.Plugin) db_common.QueryWithArgs {
	return db_common.QueryWithArgs{
		Query: fmt.Sprintf(`INSERT INTO %s.%s (
plugin,
version,
plugin_instance,
memory_max_mb,
limiters,                
file_name,
start_line_number,
end_line_number
)
	VALUES($1,$2,$3,$4,$5,$6,$7,$8)`, constants.InternalSchema, constants.PluginInstanceTable),
		Args: []any{
			plugin.Plugin,
			plugin.Version,
			plugin.Instance,
			plugin.MemoryMaxMb,
			plugin.Limiters,
			plugin.FileName,
			plugin.StartLineNumber,
			plugin.EndLineNumber,
		},
	}
}

func GetPluginTableDropSql() db_common.QueryWithArgs {
	return db_common.QueryWithArgs{
		Query: fmt.Sprintf(
			`DROP TABLE IF EXISTS %s.%s;`,
			constants.InternalSchema,
			constants.PluginInstanceTable,
		),
	}
}

func GetPluginTableGrantSql() db_common.QueryWithArgs {
	return db_common.QueryWithArgs{
		Query: fmt.Sprintf(
			`GRANT SELECT ON TABLE %s.%s to %s;`,
			constants.InternalSchema,
			constants.PluginInstanceTable,
			constants.DatabaseUsersRole,
		),
	}
}
